@@ -32,12 +32,10 @@ LNRTQ <- function(RT,
   ## XG = number of iterations for the MCMC algorithm
   
   if (XG <= 0) {
-    print("Error: XG must be > 0.")
-    return (NULL)
+    stop("XG must be > 0.")
   }
   if ((burnin <= 0) || (burnin >= XG)) {
-    print("Error: burn-in period must be between 0% and 100%.")
-    return (NULL)
+    stop("burn-in period must be between 0% and 100%.")
   }
   
   if (!missing(data) && !is.null(data)) {
@@ -72,11 +70,6 @@ LNRTQ <- function(RT,
   cat (" \n")
   cat ("   LNIRT v", packageDescription("LNIRT")$Version, "\n", sep = "")
   cat ("   ", rep('-', 20), "\n\n", sep = "")
-  # cat ("   Jean-Paul Fox \n")
-  # cat ("   Konrad Klotzke \n")
-  # cat ("   ", rep('-', 20), "\n\n", sep = "")
-  
-  #cat ("   ", rep('-', 40), "\n", sep = "")
   cat (
     "   * MCMC sampler initialized (XG:",
     XG,
@@ -86,7 +79,6 @@ LNRTQ <- function(RT,
     sep = ""
   )
   cat ("   * Response time matrix loaded (", N, "x", K, ") \n\n", sep = "")
-  #cat ("   ", rep('-', 40), "\n\n", sep = "")
   
   # Initialize progress bar
   cat ("   MCMC progress: \n")
@@ -240,7 +232,7 @@ LNRTQ <- function(RT,
       sqrt(MZ2[[jj]] / XG - MZ[[jj]] ^ 2) ## calculate posterior SD of person parameters.
   }
   
-  if (!(any(class(data) == "simLNIRTQ"))) {
+  if (!(is(data, "simLNIRTQ"))) {
     data <- NULL # only attach sim data for summary function
   }
   
